@@ -3,9 +3,9 @@ package Sah::Schema::pathname;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-14'; # DATE
+our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem path name',
@@ -58,7 +58,7 @@ Sah::Schema::pathname - Filesystem path name
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-08-14.
+This document describes version 0.019 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -86,7 +86,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -101,8 +101,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "foo";
+ my $res = $validator->($data); # => ["","foo"]
  
  # a sample invalid data
  $data = "";
