@@ -3,9 +3,9 @@ package Sah::Schema::pathname::unix;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-14'; # DATE
+our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem path name on a Unix system',
@@ -42,7 +42,7 @@ Sah::Schema::pathname::unix - Filesystem path name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-14.
+This document describes version 0.019 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -76,11 +76,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo//bar";
+ $data = "/";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "foo\0";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -91,12 +91,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo//bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "/";
+ my $res = $validator->($data); # => ["","/"]
  
  # a sample invalid data
- $data = "foo\0";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z","foo\0"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
